package com.steerinfo.dil.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.steerinfo.dil.mapper.TmstrainMeasureCommissionMapper;
import com.steerinfo.dil.model.TmstrainMeasureCommission;
import com.steerinfo.dil.service.ITmstrainMeasureCommissionService;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.util.HTTPRequestUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * TmstrainMeasureCommission服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-12-09 06:52
 * 类描述
 * 修订历史：
 * 日期：2021-12-09
 * 作者：generator
 * 参考：
 * 描述：TmstrainMeasureCommission服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "tmstrainMeasureCommissionService")
public class TmstrainMeasureCommissionServiceImpl  implements ITmstrainMeasureCommissionService {

    @Autowired
    private TmstrainMeasureCommissionMapper tmstrainMeasureCommissionMapper;

    /**
     * 批量发送计量委托
     * @return
     */
    public int batchSendMeasureCommission(Map<String, Object> map){
        List<Integer> resultIdList = (List<Integer>) map.get("resultIdList");
        int count = 0;
        for (Integer resultId : resultIdList) {
            count += addTrainMeasureCommission(resultId);
        }
        return count;
    }


    /**
     * 添加计量委托并发送计量委托
     *   resultId    装车实绩ID
     * @return
     */
    public int addTrainMeasureCommission(Integer resultId){
        Map<String, Object> map = new HashMap<>();
        map.put("resultId", resultId);
        //查询计量委托
        Map<String, Object> measureCommission = getTrainMeasureCommission(map);
        measureCommission.put("isRelationEAS", true);
        measureCommission.put("flowTo", "进厂");
        measureCommission.put("isDel", false);
        measureCommission.put("isInsert", true);
        measureCommission.put("IsAssembly", false);
        measureCommission.put("deliveryMethod", "磅重交货");
        measureCommission.put("packagesNum", 0);
        //获取计量衡ID
        map.put("calculateId", measureCommission.get("calculateId"));
        measureCommission.remove("calculateId");
        map.put("materialId", measureCommission.get("materialId"));
        map.put("resultTotalId", measureCommission.get("resultTotalId"));
        measureCommission.remove("resultTotalId");
        //添加计量委托实绩
        int i = addMeasureCommission(map);
        //添加计量委托其他数据
        i += sendMesToMeasure(measureCommission);
        return i;
    }

    /**
     * 查询没有发送过计量委托的车皮装车实绩并且到站是新区轨道衡和老区轨道衡的车皮装车实绩
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> getLoadResultToSendMC(Map<String, Object> map) {
        return tmstrainMeasureCommissionMapper.getLoadResultToSendMC(map);
    }

    /**
     * 添加火运计量委托
     * resultTotalId 火运总实绩ID
     * materialId  物资ID
     * calculateId 计量衡Id
     * @param map
     * @return
     */
    public int addMeasureCommission(Map<String, Object> map){
        TmstrainMeasureCommission tmstrainMeasureCommission = new TmstrainMeasureCommission();
        tmstrainMeasureCommission.setId(tmstrainMeasureCommissionMapper.selectMaxId());
        tmstrainMeasureCommission.setCalculateId(DataChange.dataToBigDecimal(map.get("calculateId")));
        tmstrainMeasureCommission.setMaterialId(DataChange.dataToBigDecimal(map.get("materialId")));
        tmstrainMeasureCommission.setResultTotalId(DataChange.dataToBigDecimal(map.get("resultTotalId")));
        return tmstrainMeasureCommissionMapper.insertSelective(tmstrainMeasureCommission);
    }

    /**
     * 查询计量委托
     * @param map
     * @return
     */
    @Override
    public Map<String, Object> getTrainMeasureCommission(Map<String, Object> map) {
        return tmstrainMeasureCommissionMapper.getTrainMeasureCommission(map);
    }

    /**
     * 访问计量接口方法
     * @param map
     * @return
     */
    public int sendMesToMeasure(Map<String, Object> map){
        List<Map<String, Object>> sendMap = new ArrayList<>();
        sendMap.add(map);
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("data", sendMap);

        String url = "http://172.16.33.122:44325/api/logistics/TareApplyFor";
        String jsonData = null;
        try {
            jsonData = HTTPRequestUtils.send(url, jsonObject, "utf-8");
        } catch (IOException e) {
            e.printStackTrace();
        }
        if(!"null".equals(jsonData)){
            System.out.println(jsonData);
            HashMap hashMap = JSON.parseObject(jsonData, HashMap.class);
            boolean success = (boolean) hashMap.get("success");
            System.out.println(hashMap.get("msg"));
            if(success){
                return 1;
            }
        }
        return 0;
    }
}
